.. Responsibly documentation master file, created by
   sphinx-quickstart on Mon Aug 13 16:17:54 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: readme.rst


Contents
--------

.. toctree::
  :maxdepth: 2

  dataset
  fairness
  word-embedding-bias
  demos
  about/contributing
  about/changelog
  License <about/license>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
